@@ -1,18 +1,10 @@
 /*
- *
- *
- * Copyright (C) 2004 Matthieu Bedouet <mbedouet@no-log.org>
- * Copyright (C) 2003-2008 Sebastian Trueg <trueg@k3b.org>
- *
- * This file is part of the K3b project.
- * Copyright (C) 1998-2008 Sebastian Trueg <trueg@k3b.org>
- *
- * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
- * See the file "COPYING" for the exact licensing terms.
- */
+
+    SPDX-FileCopyrightText: 2004 Matthieu Bedouet <mbedouet@no-log.org>
+    SPDX-FileCopyrightText: 1998-2008 Sebastian Trueg <trueg@k3b.org>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 #include "k3blibsndfiledecoder.h"
 #include "k3bplugin_i18n.h"
 
@@ -26,7 +18,7 @@
 #include <stdio.h>
 #include <sndfile.h>
 
-K3B_EXPORT_PLUGIN(k3blibsndfiledecoder, K3bLibsndfileDecoderFactory)
+K_PLUGIN_CLASS_WITH_JSON(K3bLibsndfileDecoderFactory, "k3blibsndfiledecoder.json")
 
 class K3bLibsndfileDecoder::Private
 {
